@@ -16,7 +16,8 @@ class Query(models.Model):
 
     class Meta:
         ordering = ['title']
-    
+        verbose_name_plural = 'Queries'
+
     def __unicode__(self):
         return unicode(self.title)
 
@@ -27,7 +28,7 @@ class Query(models.Model):
         return swap_params(self.sql, self.params)
 
     def csv_report(self):
-        headers, data, error = self.headers_and_data()
+        headers, data, duration, error = self.headers_and_data()
         if error:
             return error
         return write_csv(headers, data)
@@ -43,11 +44,11 @@ class Query(models.Model):
 
     def headers_and_data(self):
         if not self.passes_blacklist():
-            return [], [], MSG_FAILED_BLACKLIST
+            return [], [], None, MSG_FAILED_BLACKLIST
         try:
             return execute_and_fetch_query(self.final_sql())
         except DatabaseError, e:
-            return [], [], str(e)
+            return [], [], None, str(e)
 
     def available_params(self):
         p = extract_params(self.sql)
@@ -56,4 +57,4 @@ class Query(models.Model):
         return p
 
     def get_absolute_url(self):
-        return reverse("query_detail", kwargs={'query_id': self.id})
\ No newline at end of file
+        return reverse("query_detail", kwargs={'query_id': self.id})
