@@ -3,9 +3,11 @@ import csv
 import cStringIO
 import json
 import re
+from time import time
 from explorer import app_settings
-from django.db import connection, models
+from django.db import connections, connection, models
 
+EXPLORER_PARAM_TOKEN = "$$"
 
 ## SQL Specific Things
 
@@ -15,33 +17,46 @@ def passes_blacklist(sql):
 
 
 def execute_query(sql):
-    cursor = connection.cursor()
+    conn = connections[app_settings.EXPLORER_CONNECTION_NAME] if app_settings.EXPLORER_CONNECTION_NAME else connection
+    cursor = conn.cursor()
+    start_time = time()
     cursor.execute(sql)
-    return cursor
+    end_time = time()
+    duration = (end_time - start_time) * 1000
+    return cursor, duration
 
 
 def execute_and_fetch_query(sql):
-    cursor = execute_query(sql)
+    cursor, duration = execute_query(sql)
     headers = [d[0] for d in cursor.description]
     data = [[x.encode('utf-8') if type(x) is unicode else x for x in list(r)] for r in cursor.fetchall()]
-    return headers, data, None
+    return headers, data, duration, None
 
 
+# returns schema information via django app inspection (sorted alphabetically by db table name):
+# [
+#     ("package.name -> ModelClass", "db_table_name",
+#         [
+#             ("db_column_name", "DjangoFieldType"),
+#             (...),
+#         ]
+#     )
+# ]
 def schema_info():
     ret = []
-    for app in [a for a in models.get_apps() if a.__package__ not in app_settings.EXPLORER_SCHEMA_EXCLUDE_APPS]:
+    apps = [a for a in models.get_apps() if a.__package__ not in app_settings.EXPLORER_SCHEMA_EXCLUDE_APPS]
+    for app in apps:
         for model in models.get_models(app):
-            friendly_model = "%s -> %s" % (model._meta.app_label, model._meta.object_name)
+            friendly_model = "%s -> %s" % (app.__package__, model._meta.object_name)
             cur_app = (friendly_model, str(model._meta.db_table), [])
             for f in model._meta.fields:
                 cur_app[2].append((f.get_attname_column()[1], f.get_internal_type()))
             ret.append(cur_app)
-    return ret
+    return sorted(ret, key=lambda t: t[1])  # sort by table name
 
 
 def param(name):
-    bracket = app_settings.EXPLORER_PARAM_TOKEN
-    return "%s%s%s" % (bracket, name, bracket)
+    return "%s%s%s" % (EXPLORER_PARAM_TOKEN, name, EXPLORER_PARAM_TOKEN)
 
 
 def swap_params(sql, params):
@@ -131,4 +146,4 @@ class AssertMethodIsCalled(object):
 
         # If an exception was thrown within the block, we've already failed.
         if traceback is None:
-            assert self.method_called, "method %s of %s was not called" % (self.method, self.obj)
\ No newline at end of file
+            assert self.method_called, "method %s of %s was not called" % (self.method, self.obj)
